"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.googleCloudSqlInstancePrompt = void 0;
const lodash_1 = require("lodash");
const sql_instances_1 = require("../../../lib/gcloud/sql-instances");
const search_1 = require("../../../lib/util/search");
const error_1 = require("../../../lib/util/error");
const formatInstance = (instance) => {
    const { name, region } = instance;
    return {
        name: `${name} (${region})`,
        short: name,
        value: (0, lodash_1.pick)(instance, 'connectionName', 'port'),
    };
};
const source = (0, error_1.tryCatch)((answers, input) => {
    const instances = (0, sql_instances_1.fetchGoogleCloudSqlInstances)(answers.googleCloudProject);
    const filtered = (0, search_1.searchByKey)(instances, 'connectionName', input);
    return filtered.map(formatInstance);
});
exports.googleCloudSqlInstancePrompt = {
    type: 'autocomplete',
    name: 'googleCloudSqlInstance',
    message: 'Choose Google Cloud SQL instance:',
    source,
};
